@@ -2,6 +2,17 @@ import warnings
 from astropy.utils.exceptions import AstropyWarning
 warnings.simplefilter("ignore",category=AstropyWarning)
 
+logo="""\
+ STARBUGII         *          *  __  *  __   - * --   - 
+ ---------               *      / ___ /    \   --  -      - 
+ JWST photometry in        *___---.    .___/  -   --   -
+ complex crowded fields   ./=== \  \.     \      * 
+                          | (O)  |  |     |           *
+ conor nally               \._._/ ./    _(\)   *   
+ conor.nally@ed.ac.uk     /   ~--\ ----~   \      *
+                        ---      ___       ---      
+ > %s"""
+
 
 ## HASHDEFS
 MIRI=1
